Gabbia – A Wayland kiosk
========================

Gabbia (Italian for "cage") is a Wayland compositor that runs a single
application in maximized mode. It is possible to run multiple applications
under Gabbia, but it limits interaction to one application by default.

For this reason, Gabbia is particularly suitable for kiosk applications,
home automation interfaces, music players etc. where the end user is only
allowed to interact with a single application.

However, Gabbia is not a sandbox.


Similar projects
^^^^^^^^^^^^^^^^
* `Cage <https://github.com/cage-kiosk/cage>`_
